/*-------------- Telecommunications & Signal Processing Lab ---------------
                             McGill University

Routine:
  SunAudioPort

Purpose:
  Set the output port parameters for the Sun audio device

Description:
  This program sets and/or prints the output port parameters for the Sun audio
  device.

Options:
  The command line specifies the output port.
  -g VOL, --gain=VOL
      Set the output volume (a value between 0 and 100)
  -b BAL, --balance=BAL
      Set the stereo balance (a value between 0 and 100).  The value 50
      corresponds to equal left and right volume.  For values between 0 and 50,
      the right channel volume is reduced.  For values between 50 and 100, the
      left channel volume is reduced.
  -p [+-]PORTS, --port=[+-]PORTS
      Choose the output ports.  The ports argument is a list of ports
      separated by commas.  A "+" indicates ports to be turned on, a "-"
      indicates ports to be turned off.  With neither a "+" or a "-", the
      specified ports are turned on and others are turned off.  The output
      ports are: "speaker", "headphones" and "line-out".
  -m, --mute
      Mute the output
  -u, --unmute
      Unmute the output
  -d DEV, --device=DEV
      Audio device name, default from the environment variable AUDIODEV or
      "/dev/audio".
  -h, --help
      Print a list of options and exit.
  -v, --version
      Print the version number and exit.

Environment variables:
  AUDIODEV:
  This environment variable specifies the audio device name.

Author / revision:
  P. Kabal / v1r4  1999/06/06  Copyright (C) 1999

-------------------------------------------------------------------------*/

static char rcsid[] = "$Id: SunAudioPort.c 1.12 1999/06/14 AFsp-v4r3 $";

#include <stdio.h>
#include <stdlib.h>		/* EXIT_SUCCESS */
#include <unistd.h>		/* close */

#include <libtsp.h>
#include <AD.h>
#include "SunAudioPort.h"


int
main (int argc, const char *argv[])

{
  struct AD_DevOpt DevOpt;
  int audio_fd;
  const char *AudioDev;

/* Decode options */
  SAoptions (argc, argv, &AudioDev, &DevOpt);

/* Open the audio device */
  if (AudioDev[0] == '\0')
    audio_fd = ADopenControl ("$AUDIODEV", AD_PRINT_FLAG);
  else
    audio_fd = ADopenControl (AudioDev, AD_PRINT_FLAG);

/* Set the output ports, volume and stereo balance */
  ADsetOPort (audio_fd, DevOpt.Ports, (double) DevOpt.Vol,
	      (double) DevOpt.Balance, DevOpt.Mute);

/* Print the settings */
  ADprintOPort (audio_fd);

/* Close the audio control device */
  close (audio_fd);

  return EXIT_SUCCESS;
}
